@@ -43,6 +43,7 @@
 #include "apr_dso.h"
 #include "apr_general.h"
 #include "apr_pools.h"
+#include "apr_hash.h"
 
 #if defined(AP_NEED_SET_MUTEX_PERMS)
 #  include "unixd.h"
@@ -169,6 +170,7 @@ struct imode_emoji_t {
   char  hex1byte;
   char  hex2byte;
   char* string;
+  char* color;
   char *description;
 };
 
@@ -278,11 +280,14 @@ typedef enum {
   tagPLAINTEXT,
   tagBLINK,
   tagMARQUEE,
+  tagLINK,
   tagNLMARK,      /* New Line Code */
+  tagOBJECT,
+  tagPARAM,
+  tagCAPTION,
 } tag_type;
 
 typedef struct mod_chxj_config mod_chxj_config;
-typedef struct mod_chxj_req_config_t mod_chxj_req_config;
 
 #if defined(USE_MYSQL_COOKIE)
 #  include "chxj_mysql.h"
@@ -335,6 +340,7 @@ struct mod_chxj_config {
   device_table_list     *devices;
   emoji_t               *emoji;
   emoji_t               *emoji_tail;
+  int                   imode_emoji_color;
   char                  *server_side_encoding;
 
   char                  *dir; /* for LOG */
@@ -346,6 +352,8 @@ struct mod_chxj_config {
   cookie_store_type_t   cookie_store_type;
   int                   cookie_lazy_mode;
   char                  *cookie_dbm_type;
+  
+  int                   detect_device_type; /* XML|TSV */
 
 #if defined(USE_MYSQL_COOKIE)
   mysql_t               mysql;
@@ -361,13 +369,13 @@ struct mod_chxj_config {
   chxj_new_line_type_t  new_line_type;
 
   char                  *post_log;              /* post log environment name. */
-};
+  
+  apr_array_header_t    *device_keys;           /* TSV header array */
+  apr_hash_t            *device_hash;           /* TSV device data hash table */
 
-struct mod_chxj_req_config_t {
-  char               *user_agent;
-  device_table       *spec;
-  ap_filter_t        *f;
-  chxjconvrule_entry *entryp;
+  int                   image_rewrite;
+  char                  *image_rewrite_url;
+  int                   image_rewrite_mode;
 };
 
 #define IS_COOKIE_STORE_DBM(X)      ((X) == COOKIE_STORE_TYPE_DBM)
@@ -383,6 +391,7 @@ struct mod_chxj_req_config_t {
 #define CONVRULE_ENGINE_ON_BIT        (0x00000001)
 #define CONVRULE_ENGINE_OFF_BIT       (0x00000002)
 #define CONVRULE_COOKIE_ON_BIT        (0x00000004)
+#define CONVRULE_CSS_ON_BIT           (0x10000000)
 #define CONVRULE_Z2H_ON_BIT           (0x00000008)
 #define CONVRULE_Z2H_OFF_BIT          (0x00000010)
 #define CONVRULE_Z2H_ALPHA_ON_BIT     (0x00000020)
@@ -401,6 +410,8 @@ struct mod_chxj_req_config_t {
 #define CONVRULE_ENGINE_OFF_CMD       "EngineOff"
 #define CONVRULE_COOKIE_ON_CMD        "CookieOn"
 #define CONVRULE_COOKIE_OFF_CMD       "CookieOff"
+#define CONVRULE_CSS_ON_CMD           "CssOn"
+#define CONVRULE_CSS_OFF_CMD          "CssOff"
 #define CONVRULE_Z2H_ON_CMD           "Z2hOn"
 #define CONVRULE_Z2H_OFF_CMD          "Z2hOff"
 #define CONVRULE_Z2H_ALPHA_ON_CMD     "Z2hAlphaOn"
@@ -426,6 +437,8 @@ struct mod_chxj_req_config_t {
 #define CONVRULE_PC_FLAG_OFF_BIT      (0x00000002)
 
 
+#define IS_CSS_ON(X)                  ((X)->action & CONVRULE_CSS_ON_BIT)
+
 typedef struct {
   apr_global_mutex_t* cookie_db_lock;
 } mod_chxj_global_config;
@@ -457,6 +470,31 @@ module AP_MODULE_DECLARE_DATA chxj_module;
 #define CHXJ_IMG_OFF    (1)
 #define CHXJ_IMG_NONE   (0)
 
+#define CHXJ_IMODE_EMOJI_COLOR_ON   (3)
+#define CHXJ_IMODE_EMOJI_COLOR_AUTO (2)
+#define CHXJ_IMODE_EMOJI_COLOR_OFF  (1)
+#define CHXJ_IMODE_EMOJI_COLOR_NONE (0)
+
+#define CHXJ_ADD_DETECT_DEVICE_TYPE_TSV     (1)
+#define CHXJ_ADD_DETECT_DEVICE_TYPE_NONE    (0)
+
+#define CHXJ_PROVIDER_UNKNOWN  (0)
+#define CHXJ_PROVIDER_DOCOMO   (1)
+#define CHXJ_PROVIDER_AU       (2)
+#define CHXJ_PROVIDER_SOFTBANK (3)
+
+#define CHXJ_IMG_REWRITE_ON     (2)
+#define CHXJ_IMG_REWRITE_OFF    (1)
+#define CHXJ_IMG_REWRITE_NONE   (0)
+
+#define CHXJ_IMG_REWRITE_MODE_ALL  (3)
+#define CHXJ_IMG_REWRITE_MODE_USER (2)
+#define CHXJ_IMG_REWRITE_MODE_TAG  (1)
+#define CHXJ_IMG_REWRITE_MODE_NONE (0)
+
+#define CHXJ_IMG_REWRITE_URL_STRING             "_x-chxj_imgrewrite=on"
+#define CHXJ_IMG_X_HTTP_IMAGE_FILENAME          "X-Chxj-Image-Filename"
+#define CHXJ_IMG_X_HTTP_IMAGE_TYPE              "X-Chxj-Image-Type"
 
 #define DBG(X,args...)  chxj_log_rerror(APLOG_MARK,APLOG_DEBUG,0,(request_rec*)(X),##args)
 #define SDBG(X,Y)       chxj_log_error(APLOG_MARK,APLOG_DEBUG,0,(X),(Y))
@@ -472,6 +510,7 @@ extern tag_handler  chtml20_handler[];
 extern tag_handler  chtml30_handler[];
 extern tag_handler  chtml40_handler[];
 extern tag_handler  chtml50_handler[];
+extern tag_handler  ixhtml10_handler[];
 extern tag_handler  xhtml_handler[];
 extern tag_handler  hdml_handler[];
 extern tag_handler  jhtml_handler[];
@@ -492,9 +531,6 @@ extern char *chxj_node_convert_chxjif_only(
   apr_size_t   *len
 );
 
-extern void chxj_remove_filter(request_rec *r);
-extern mod_chxj_req_config *chxj_get_req_config(request_rec *r);
-
 #define IMAGE_CACHE_LIMIT_FMT_LEN  (20)
 
 
@@ -504,23 +540,6 @@ extern void *rpl_malloc(size_t n);
 
 
 #define TO_ADDR(X) ((unsigned int)(apr_size_t)(X))
-#if APR_MAJOR_VERSION < 1
-  #ifndef APR_FOPEN_READ
-    #define APR_FOPEN_READ APR_READ
-  #endif
-  #ifndef APR_FOPEN_BUFFERED
-    #define APR_FOPEN_BUFFERED APR_BUFFERED
-  #endif
-  #ifndef APR_FOPEN_BINARY
-    #define APR_FOPEN_BINARY APR_BINARY
-  #endif
-  #ifndef APR_FOPEN_CREATE
-    #define APR_FOPEN_CREATE APR_CREATE
-  #endif
-  #ifndef APR_FOPEN_WRITE
-    #define APR_FOPEN_WRITE APR_WRITE
-  #endif
-#endif
 #endif
 /*
  * vim:ts=2 et
