@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -18,6 +18,7 @@
 #include "chxj_encoding.h"
 #include "chxj_apply_convrule.h"
 #include "chxj_url_encode.h"
+#include "chxj_dump_string.h"
 #include <errno.h>
 #include <iconv.h>
 
@@ -34,45 +35,35 @@ chxj_encoding(request_rec *r, const char *src, apr_size_t *len)
   apr_size_t          ilen;
   apr_size_t          olen;
   mod_chxj_config     *dconf;
-  mod_chxj_req_config *req_conf;
   chxjconvrule_entry  *entryp;
   apr_pool_t          *pool;
 
 
-  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
+  DBG(r,"REQ[%X] start chxj_encoding()", (unsigned int)(apr_size_t)r);
 
   dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
 
   if (dconf == NULL) {
-    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"none encoding.");
+    DBG(r,"REQ[%X] end   chxj_encoding()", (unsigned int)(apr_size_t)r);
     return (char*)src;
   }
   if ((int)*len < 0) {
-    ERR(r, "REQ[%X] runtime exception: chxj_encoding(): invalid string size.[%d]", TO_ADDR(r),(int)*len);
-    DBG(r, "REQ[%X] end %s()",TO_ADDR(r),__func__);
+    ERR(r, "runtime exception: chxj_encoding(): invalid string size.[%d]", (int)*len);
+    DBG(r,"REQ[%X] end   chxj_encoding()", (unsigned int)(apr_size_t)r);
     return (char *)apr_pstrdup(r->pool, "");
   }
 
-  req_conf = chxj_get_req_config(r);
-  /*-------------------------------------------------------------------------*/
-  /* already setup entryp if request_conf->user_agent is not null            */
-  /*-------------------------------------------------------------------------*/
-  if (req_conf->user_agent) {
-    entryp = req_conf->entryp;
-  }
-  else {
-    entryp = chxj_apply_convrule(r, dconf->convrules);
-  }
+  entryp = chxj_apply_convrule(r, dconf->convrules);
   if (entryp->encoding == NULL) {
-    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] none encoding.", (unsigned int)(apr_size_t)r);
+    DBG(r,"REQ[%X] end   chxj_encoding()", (unsigned int)(apr_size_t)r);
     return (char *)src;
   }
 
   if (STRCASEEQ('n','N',"none", entryp->encoding)) {
-    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] none encoding.", (unsigned int)(apr_size_t)r);
+    DBG(r,"REQ[%X] end   chxj_encoding()", (unsigned int)(apr_size_t)r);
     return (char*)src;
   }
 
@@ -81,6 +72,7 @@ chxj_encoding(request_rec *r, const char *src, apr_size_t *len)
   ibuf = apr_palloc(pool, ilen+1);
   if (ibuf == NULL) {
     ERR(r, "runtime exception: chxj_encoding(): Out of memory.");
+    DBG(r,"REQ[%X] end chxj_encoding()", (unsigned int)(apr_size_t)r);
     return (char *)src;
   }
   memset(ibuf, 0, ilen+1);
@@ -89,36 +81,36 @@ chxj_encoding(request_rec *r, const char *src, apr_size_t *len)
   olen = ilen * 4 + 1;
   spos = obuf = apr_palloc(pool, olen);
   if (obuf == NULL) {
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] end   chxj_encoding()", (unsigned int)(apr_size_t)r);
     return ibuf;
   }
-  DBG(r,"REQ[%X] encode convert [%s] -> [%s]", TO_ADDR(r),entryp->encoding, "CP932");
+  DBG(r,"REQ[%X] encode convert [%s] -> [%s]", (unsigned int)(apr_size_t)r, entryp->encoding, "CP932");
 
   memset(obuf, 0, olen);
   cd = iconv_open("CP932", entryp->encoding);
   if (cd == (iconv_t)-1) {
     if (EINVAL == errno) {
-      ERR(r, "REQ[%X] The conversion from %s to %s is not supported by the implementation.", TO_ADDR(r),entryp->encoding, "CP932");
+      ERR(r, "The conversion from %s to %s is not supported by the implementation.", entryp->encoding, "CP932");
     }
     else {
-      ERR(r, "REQ[%X] iconv open failed. from:[%s] to:[%s] errno:[%d]", TO_ADDR(r),entryp->encoding, "CP932", errno);
+      ERR(r, "iconv open failed. from:[%s] to:[%s] errno:[%d]", entryp->encoding, "CP932", errno);
     }
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] end   chxj_encoding()", (unsigned int)(apr_size_t)r);
     return ibuf;
   }
   while (ilen > 0) {
     result = iconv(cd, &ibuf, &ilen, &obuf, &olen);
     if (result == (size_t)(-1)) {
       if (E2BIG == errno) {
-        ERR(r, "REQ[%X] There is not sufficient room at *outbuf.",TO_ADDR(r));
+        ERR(r, "There is not sufficient room at *outbuf.");
         break;
       }
       else if (EILSEQ == errno) {
-        ERR(r, "REQ[%X] %s:%d An invalid multibyte sequence has been encountered in the input. input:[%s]", TO_ADDR(r),__FILE__,__LINE__,ibuf);
+        ERR(r, "%s:%d An invalid multibyte sequence has been encountered in the input. input:[%s]", __FILE__,__LINE__,ibuf);
         chxj_convert_illegal_charactor_sequence(r, entryp, &ibuf, &ilen, &obuf, &olen);
       }
       else if (EINVAL == errno) {
-        ERR(r, "REQ[%X] An incomplete multibyte sequence has been encountered in the input. input:[%s]", TO_ADDR(r),ibuf);
+        ERR(r, "An incomplete multibyte sequence has been encountered in the input. input:[%s]", ibuf);
         break;
       }
     }
@@ -126,8 +118,8 @@ chxj_encoding(request_rec *r, const char *src, apr_size_t *len)
   *len = strlen(spos);
   iconv_close(cd);
 
-  DBG(r,"REQ[%X] len=[%d] obuf=[%.*s]", TO_ADDR(r),(int)*len, (int)*len, spos);
-  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+  chxj_dump_string(r, APLOG_MARK, "RESULT Convert Encoding", spos, *len);
+  DBG(r,"REQ[%X] end   chxj_encoding()", (unsigned int)(apr_size_t)r);
   return spos;
 }
 
@@ -142,7 +134,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 2;
-      DBG(r, "REQ[%X] passed 2byte.",TO_ADDR(r));
+      DBG(r, "passed 2byte.");
     }
     else if ((0xf0 & **ibuf) == 0xe0) {
       /* 3byte charactor */
@@ -150,7 +142,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf +=3;
-      DBG(r, "REQ[%X] passed 3byte.",TO_ADDR(r));
+      DBG(r, "passed 3byte.");
     }
     else if ((0xf8 & **ibuf) == 0xf0) {
       /* 4byte charactor */
@@ -158,7 +150,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf +=4;
-      DBG(r, "REQ[%X] passed 4byte.",TO_ADDR(r));
+      DBG(r, "passed 4byte.");
     }
     else if ((0xc0 & **ibuf) == 0x80) {
       /* 1byte charactor */
@@ -166,7 +158,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 1;
-      DBG(r, "REQ[%X] passed 1byte.",TO_ADDR(r));
+      DBG(r, "passed 1byte.");
     }
     else {
       /* unknown charactor */
@@ -174,7 +166,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 1;
-      DBG(r, "REQ[%X] passed 1byte.",TO_ADDR(r));
+      DBG(r, "passed 1byte.");
     }
   }
   else if (STRCASEEQ('e','E', "EUCJP",               entryp->encoding)
@@ -192,7 +184,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf +=3;
-      DBG(r, "REQ[%X] passed 3byte.",TO_ADDR(r));
+      DBG(r, "passed 3byte.");
     }
     else {
       /* 2byte charactor */
@@ -200,7 +192,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 2;
-      DBG(r, "REQ[%X] passed 2byte.",TO_ADDR(r));
+      DBG(r, "passed 2byte.");
     }
   }
   else if (STRCASEEQ('c', 'C', "CP932",     entryp->encoding)
@@ -222,7 +214,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 2;
-      DBG(r, "REQ[%X] passed 2byte.", TO_ADDR(r));
+      DBG(r, "passed 2byte.");
     }
     else {
       /* 1byte charactor */
@@ -230,7 +222,7 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
       *obuf += 1;
       *olen -= 1;
       *ibuf += 1;
-      DBG(r, "REQ[%X] passed 1byte.",TO_ADDR(r));
+      DBG(r, "passed 1byte.");
     }
   }
   else {
@@ -239,17 +231,17 @@ chxj_convert_illegal_charactor_sequence(request_rec *r, chxjconvrule_entry  *ent
     *obuf += 1;
     *olen -= 1;
     *ibuf += 1;
-    DBG(r, "REQ[%X] passed 1byte.", TO_ADDR(r));
+    DBG(r, "passed 1byte.");
   }
   if (ibuf && *ibuf) {
     *ilen = strlen(*ibuf);
-    DBG(r, "REQ[%X] new len = [%" APR_SIZE_T_FMT "].", TO_ADDR(r),(apr_size_t)*ilen);
+    DBG(r, "new len = [%" APR_SIZE_T_FMT "].", (apr_size_t)*ilen);
   }
 }
 
 
 char *
-chxj_rencoding(request_rec *r, const char *src, apr_size_t *len)
+chxj_rencoding(request_rec *r, const char *src, apr_size_t *len,const char *enc)
 {
   char                *obuf;
   char                *ibuf;
@@ -260,50 +252,40 @@ chxj_rencoding(request_rec *r, const char *src, apr_size_t *len)
   apr_size_t          ilen;
   apr_size_t          olen;
   mod_chxj_config     *dconf;
-  mod_chxj_req_config *req_conf;
   chxjconvrule_entry  *entryp;
 
-  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
+  DBG(r,"REQ[%X] start chxj_rencoding()", (unsigned int)(apr_size_t)r);
 
   if ((int)*len < 0) {
-    ERR(r, "REQ[%X] runtime exception: chxj_rencoding(): invalid string size.[%d]", TO_ADDR(r),(int)*len);
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    ERR(r, "runtime exception: chxj_rencoding(): invalid string size.[%d]", (int)*len);
+    DBG(r,"REQ[%X] end   chxj_rencoding()", (unsigned int)(apr_size_t)r);
     return (char *)apr_pstrdup(r->pool, "");
   }
 
   dconf = chxj_get_module_config(r->per_dir_config, &chxj_module);
   if (! dconf) {
-    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] none encoding.", (unsigned int)(apr_size_t)r);
+    DBG(r,"REQ[%X] end   chxj_rencoding()", (unsigned int)(apr_size_t)r);
     return (char*)src;
   }
 
-  req_conf = chxj_get_req_config(r);
-  /*-------------------------------------------------------------------------*/
-  /* already setup entryp if request_conf->user_agent is not null            */
-  /*-------------------------------------------------------------------------*/
-  if (req_conf->user_agent) {
-    entryp = req_conf->entryp;
-  }
-  else {
-    entryp = chxj_apply_convrule(r, dconf->convrules);
-  }
+  entryp = chxj_apply_convrule(r, dconf->convrules);
   if (! entryp->encoding) {
-    DBG(r,"REQ[%X] none encoding.",TO_ADDR(r));
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] none encoding.", (unsigned int)(apr_size_t)r);
+    DBG(r,"REQ[%X] end   chxj_rencoding()", (unsigned int)(apr_size_t)r);
     return (char*)src;
   }
 
   if (STRCASEEQ('n','N',"none", entryp->encoding)) {
-    DBG(r,"REQ[%X] none encoding.", TO_ADDR(r));
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] none encoding.", (unsigned int)(apr_size_t)r);
+    DBG(r,"REQ[%X] end   chxj_rencoding()", (unsigned int)(apr_size_t)r);
     return (char*)src;
   }
 
   ilen = *len;
   ibuf = apr_palloc(r->pool, ilen+1);
   if (! ibuf) {
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] end   chxj_rencoding()", (unsigned int)(apr_size_t)r);
     return (char*)src;
   }
 
@@ -313,19 +295,25 @@ chxj_rencoding(request_rec *r, const char *src, apr_size_t *len)
   olen = ilen * 4 + 1;
   spos = obuf = apr_palloc(r->pool, olen);
   if (! obuf) {
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] end   chxj_rencoding()", (unsigned int)(apr_size_t)r);
     return ibuf;
   }
-  DBG(r,"REQ[%X] encode convert [%s] -> [%s]", TO_ADDR(r),"CP932", entryp->encoding);
-
+  char *from_enc = (char *)enc;
+  if (!enc){
+    from_enc = "CP932";
+  }
+  if (strcasecmp(enc,"Shift_JIS") == 0){
+    from_enc = "CP932";
+  }
+  DBG(r,"encode convert [%s] -> [%s]", from_enc, entryp->encoding);
   memset(obuf, 0, olen);
 
-  cd = iconv_open(entryp->encoding, "CP932");
+  cd = iconv_open(entryp->encoding, from_enc);
   if (cd == (iconv_t)-1) {
     if (EINVAL == errno) {
-      ERR(r, "REQ[%X] The conversion from %s to %s is not supported by the implementation.", TO_ADDR(r),"CP932", entryp->encoding);
+      ERR(r, "The conversion from %s to %s is not supported by the implementation.", "CP932", entryp->encoding);
     }
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r,"REQ[%X] end   chxj_rencoding()", (unsigned int)(apr_size_t)r);
     return ibuf;
   }
 
@@ -333,15 +321,15 @@ chxj_rencoding(request_rec *r, const char *src, apr_size_t *len)
     result = iconv(cd, &ibuf, &ilen, &obuf, &olen);
     if (result == (size_t)(-1)) {
       if (E2BIG == errno) {
-        ERR(r, "REQ[%X] There is not sufficient room at *outbuf",TO_ADDR(r));
+        ERR(r, "There is not sufficient room at *outbuf");
         break;
       }
       else if (EILSEQ == errno) {
-        ERR(r, "REQ[%X] An invalid multibyte sequence has been encountered in the input. input:[%s]", TO_ADDR(r),ibuf);
+        ERR(r, "An invalid multibyte sequence has been encountered in the input. input:[%s]", ibuf);
         chxj_convert_illegal_charactor_sequence(r, entryp, &ibuf, &ilen, &obuf, &olen);
       }
       else if (EINVAL == errno) {
-        ERR(r, "REQ[%X] An incomplete multibyte sequence has been encountered in the input. input:[%s]", TO_ADDR(r),ibuf);
+        ERR(r, "An incomplete multibyte sequence has been encountered in the input. input:[%s]", ibuf);
         break;
       }
     }
@@ -350,14 +338,15 @@ chxj_rencoding(request_rec *r, const char *src, apr_size_t *len)
   *len = strlen(spos);
   iconv_close(cd);
 
-  DBG(r,"REQ[%X] len=[%d] obuf=[%.*s]", TO_ADDR(r),(int)*len, (int)*len, spos);
-  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+  chxj_dump_string(r, APLOG_MARK, "RESULT Convert REncoding", spos, *len);
+  DBG(r,"REQ[%X] end   chxj_rencoding()", (unsigned int)(apr_size_t)r);
+
   return spos;
 }
 
 
 char *
-chxj_encoding_parameter(request_rec *r, const char *value)
+chxj_encoding_parameter(request_rec *r, const char *value, int xmlflag)
 {
   char *src;
   char *src_sv;
@@ -373,7 +362,7 @@ chxj_encoding_parameter(request_rec *r, const char *value)
 
   int   use_amp_flag;
   
-  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
+  DBG(r, "REQ[%X] start chxj_encoding_parameter()", TO_ADDR(r));
 
   src = apr_pstrdup(r->pool, value);
 
@@ -387,7 +376,7 @@ chxj_encoding_parameter(request_rec *r, const char *value)
 
   spos = strchr(src, '?');
   if (!spos) {
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r, "REQ[%X] end   chxj_encoding_parameter()", (unsigned int)(apr_size_t)r);
     if (anchor_pos) {
       return apr_pstrcat(r->pool, src, "#", anchor, NULL);
     } else {
@@ -404,7 +393,7 @@ chxj_encoding_parameter(request_rec *r, const char *value)
     apr_size_t len;
     char *sep_pos;
 
-    use_amp_flag = 0;
+    use_amp_flag = (xmlflag) ? 1 : 0;
 
     pair = apr_strtok(spos, "&", &pstat);
     spos = NULL;
@@ -474,7 +463,7 @@ chxj_encoding_parameter(request_rec *r, const char *value)
       }
     }
   }
-  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+  DBG(r, "REQ[%X] end   chxj_encoding_parameter()", TO_ADDR(r));
 
   if (anchor_pos) {
     return apr_pstrcat(r->pool, src_sv, "?", param, "#", anchor, NULL);
@@ -482,6 +471,72 @@ chxj_encoding_parameter(request_rec *r, const char *value)
     return apr_pstrcat(r->pool, src_sv, "?", param, NULL);
   }
 }
+
+
+char *
+chxj_iconv(request_rec *r, apr_pool_t *pool, const char *src, apr_size_t *len, const char *from, const char *to)
+{
+  char                *obuf;
+  char                *ibuf;
+  char                *spos;
+  
+  iconv_t             cd;
+  size_t              result;
+  apr_size_t          ilen;
+  apr_size_t          olen;
+
+
+  if ((int)*len < 0) {
+    ERR(r, "runtime exception: chxj_iconv(): invalid string size.[%d]", (int)*len);
+    return (char *)apr_pstrdup(pool, "");
+  }
+
+  ilen = *len;
+  ibuf = apr_palloc(pool, ilen+1);
+  if (ibuf == NULL) {
+    ERR(r, "runtime exception: chxj_iconv(): Out of memory.");
+    return (char *)src;
+  }
+  memset(ibuf, 0, ilen+1);
+  memcpy(ibuf, src, ilen);
+
+  olen = ilen * 4 + 1;
+  spos = obuf = apr_palloc(pool, olen);
+  if (obuf == NULL) {
+    ERR(r, "%s:%d runtime exception: chxj_iconv(): Out of memory", APLOG_MARK);
+    return ibuf;
+  }
+  memset(obuf, 0, olen);
+  cd = iconv_open(to, from);
+  if (cd == (iconv_t)-1) {
+    if (EINVAL == errno) {
+      ERR(r, "The conversion from %s to %s is not supported by the implementation.", from, to);
+    }
+    else {
+      ERR(r, "iconv open failed. from:[%s] to:[%s] errno:[%d]", from, to, errno);
+    }
+    return ibuf;
+  }
+  while (ilen > 0) {
+    result = iconv(cd, &ibuf, &ilen, &obuf, &olen);
+    if (result == (size_t)(-1)) {
+      if (E2BIG == errno) {
+        ERR(r, "There is not sufficient room at *outbuf.");
+      }
+      else if (EILSEQ == errno) {
+        ERR(r, "An invalid multibyte sequence has been encountered in the input. input:[%s]", ibuf);
+      }
+      else if (EINVAL == errno) {
+        ERR(r, "An incomplete multibyte sequence has been encountered in the input. input:[%s]", ibuf);
+      }
+      break;
+    }
+  }
+  *len = strlen(spos);
+  iconv_close(cd);
+
+  return spos;
+}
 /*
  * vim:ts=2 et
  */
