@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -169,7 +169,7 @@ chxj_safe_to_jreserved_tag(request_rec *r, const char *src)
 }
 
 char *
-chxj_jreserved_tag_to_safe_for_query_string(request_rec *r, const char *query_string, chxjconvrule_entry  *entryp)
+chxj_jreserved_tag_to_safe_for_query_string(request_rec *r, const char *query_string, chxjconvrule_entry  *entryp, int xmlflag)
 {
   apr_pool_t *pool;
   apr_pool_create(&pool, r->pool);
@@ -187,33 +187,49 @@ chxj_jreserved_tag_to_safe_for_query_string(request_rec *r, const char *query_st
   s++;
   fname = apr_pstrdup(pool, result);
   result = NULL;
-
-  char *pstat;
+	
+	char *pstat;
   char *pstat2;
   for (;;) {
-    char *pair = apr_strtok(s, "&", &pstat);
+    char *pair = NULL;
+    pair = apr_strtok(s, "&", &pstat);
+    
     if (! pair) break;
     s = NULL;
+		
+		if(strncasecmp(pair,"amp;",4) == 0){
+			pair += 4;
+		}
+		
     char *key = apr_strtok(pair, "=",  &pstat2);
     char *val = "";
     if (key) {
       val = apr_strtok(NULL, "=", &pstat2);
+			
       if (!val) val = "";
     }
     char *tmp = NULL;
     if (strcasecmp(key, "guid") == 0) {
       tmp = apr_psprintf(pool, "%s=%s", key, val);
       if (result) {
-        result = apr_pstrcat(pool, result, "&" ,tmp, NULL);
+				if(xmlflag)
+					result = apr_pstrcat(pool, result, "&amp;" ,tmp, NULL);
+				else
+        	result = apr_pstrcat(pool, result, "&" ,tmp, NULL);
       }
       else {
         result = tmp;
       }
     }
     else {
-      tmp = apr_psprintf(pool, "%s=%s", chxj_jreserved_to_safe_tag(r, key, entryp),  val);
+      tmp = apr_psprintf(pool, "%s=%s", chxj_jreserved_to_safe_tag(r, key, entryp), chxj_url_decode(pool, val));
       if (result) {
-        result = apr_pstrcat(pool, result, "&" ,tmp, NULL);
+        if (xmlflag) {
+          result = apr_pstrcat(pool, result, "&amp;" ,tmp, NULL);
+        }
+        else {
+          result = apr_pstrcat(pool, result, "&" ,tmp, NULL);
+        }
       }
       else {
         result = tmp;
