@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,6 +15,8 @@
  * limitations under the License.
  */
 #include "chxj_str_util.h"
+#if !defined (__CHXJ_STR_UTIL_C__)
+#define __CHXJ_STR_UTIL_C__
 
 int
 chxj_chk_numeric(const char *s)
@@ -40,9 +42,8 @@ chxj_chk_numeric(const char *s)
 }
 
 
-
 int
-chxj_atoi(const char *s)
+_chxj_atoi(const char *s, int base)
 {
   int len;
   int ii;
@@ -57,7 +58,7 @@ chxj_atoi(const char *s)
   len = strlen(s);
 
   for (ii=0; ii < len && break_flag == 0; ii++) {
-    result *= 10;
+    result *= base;
     switch(s[ii]) {
     case '0': result += 0; break; 
     case '1': result += 1; break;
@@ -69,8 +70,14 @@ chxj_atoi(const char *s)
     case '7': result += 7; break;
     case '8': result += 8; break;
     case '9': result += 9; break;
+    case 'a': case 'A': result += 10; break;
+    case 'b': case 'B': result += 11; break;
+    case 'c': case 'C': result += 12; break;
+    case 'd': case 'D': result += 13; break;
+    case 'e': case 'E': result += 14; break;
+    case 'f': case 'F': result += 15; break;
     case '-': 
-      result /= 10;
+      result /= base;
       if (ii != 0) {
         break_flag = 1;
         break;
@@ -79,7 +86,7 @@ chxj_atoi(const char *s)
       break;
 
     case '+':
-      result /= 10;
+      result /= base;
       if (ii != 0) {
         break_flag = 1;
         break;
@@ -88,7 +95,7 @@ chxj_atoi(const char *s)
 
     default: 
       break_flag = 1;
-      result /= 10;
+      result /= base;
       break;
     }
   }
@@ -99,6 +106,17 @@ chxj_atoi(const char *s)
   return result;
 }
 
+int
+chxj_atoi(const char *s)
+{
+  return _chxj_atoi(s, 10);
+}
+int
+chxj_axtoi(const char *s)
+{
+  return _chxj_atoi(s, 16);
+}
+
 int
 chxj_strcasenrcmp(apr_pool_t *p, const char *s1, const char *s2, int n)
 {
@@ -193,6 +211,27 @@ chxj_add_slash_to_doublequote(apr_pool_t *pool, const char *str)
   }
   return ret;
 }
+
+
+int
+chxj_strcount(const char *s, const char *str)
+{
+  register char *p = (char *)s;
+  register char i;
+  int len = strlen(str);
+  int count = 0;
+  while (*p) {
+    for (i=0; i<len; i++) {
+      if (*p == str[(unsigned int)i]) {
+        count++;
+        break;
+      }
+    }
+    p++;
+  }
+  return count;
+}
+#endif
 /*
  * vim:ts=2 et
  */
