@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -468,7 +468,7 @@ chxj_chxjif_is_mine(device_table *spec, Doc *doc, Node *tag)
     char *value = qs_get_attr_value(doc,attr);
     if ((*name == 'l' || *name == 'L') && strcasecmp(name, "lang") == 0) {
 
-      DBG(r,"REQ[%X] lang found [%s] spec [%d]", TO_ADDR(r), value, spec->html_spec_type);
+      DBG(r, "lang found [%s] spec [%d]", value, spec->html_spec_type);
       if (STRCASEEQ('a','A',"all",value)) {
         return 1;
       }
@@ -510,7 +510,7 @@ chxj_chxjif_is_mine(device_table *spec, Doc *doc, Node *tag)
           break;
         }
       }
-      else if (STRCASEEQ('c','C',"cxhtml",value)) {
+      else if (STRCASEEQ('i','I',"ixhtml",value)) {
         switch (spec->html_spec_type) {
         case CHXJ_SPEC_Chtml_6_0:
         case CHXJ_SPEC_Chtml_7_0:
@@ -717,15 +717,13 @@ chxj_delete_chxj_cc_param(
   char        *s;
   int         xmlFlag = 0;
 
-  DBG(r,"REQ[%X] start %s()",TO_ADDR(r),__func__);
-  DBG(r,"REQ[%X] str:[%s]", TO_ADDR(r),str);
+  DBG(r, "REQ[%X] start chxj_delete_chxj_cc_param() str:[%s]", TO_ADDR(r),str);
 
   apr_pool_create(&pool, r->pool);
   s = apr_pstrdup(pool, str);
 
   if (!s) {
-    ERR(r,"REQ[%X] Memory Allocation Error", TO_ADDR(r));
-    DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+    DBG(r, "REQ[%X] end chxj_delete_chxj_cc_param() Memory Allocation Error", TO_ADDR(r));
     return NULL;
   }
   char *result = NULL;
@@ -755,8 +753,8 @@ chxj_delete_chxj_cc_param(
       }
     }
   }
-  DBG(r,"REQ[%X] result:[%s]", TO_ADDR(r), result);
-  DBG(r,"REQ[%X] end %s()",TO_ADDR(r),__func__);
+  DBG(r, "REQ[%X] result:[%s]", TO_ADDR(r), result);
+  DBG(r, "REQ[%X] end chxj_delete_chxj_cc_param() ", TO_ADDR(r));
   return result;
 }
 /*
