@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2005-2011 Atsushi Konno All rights reserved.
+ * Copyright (C) 2005-2009 Atsushi Konno All rights reserved.
  * Copyright (C) 2005 QSDN,Inc. All rights reserved.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -433,7 +433,7 @@ qs_dump_node(Doc *doc, Node *node, int indent)
                       (char *)qs_get_node_value(doc,p));
     }
     else {
-      DBG(doc->r,"%*.*sNode:[%s]\n", indent,indent," ", qs_get_node_name(doc,p));
+      DBG(doc->r,"%*.*sNode:[%s] prev:[%x]\n", indent,indent," ", qs_get_node_name(doc,p), (unsigned int)(apr_size_t)p->prev);
     }
     for (attr = (Attr *)qs_get_attr(doc,p); attr; attr = (Attr *)qs_get_next_attr(doc,attr)) {
       DBG(doc->r,"%*.*s  ATTR:[%s]\n", indent,indent," ", (char *)qs_get_attr_name(doc,attr));
@@ -557,6 +557,7 @@ qs_init_root_node(Doc *doc)
     QX_LOGGER_FATAL("Out Of Memory");
   }
 
+  doc->root_node->prev   = NULL;
   doc->root_node->next   = NULL;
   doc->root_node->parent = NULL;
   doc->root_node->child  = NULL;
@@ -577,6 +578,7 @@ qs_init_root_node(Doc *doc)
 void
 qs_add_child_node(Doc *doc,Node *node) 
 {
+  node->prev       = NULL;
   node->next       = NULL;
   node->child      = NULL;
   node->child_tail = NULL;
@@ -589,6 +591,7 @@ qs_add_child_node(Doc *doc,Node *node)
 #ifdef DEBUG
     QX_LOGGER_DEBUG("search child free node");
 #endif
+    node->prev = doc->now_parent_node->child_tail;
     doc->now_parent_node->child_tail->next = node;
     doc->now_parent_node->child_tail       = node;
   }
@@ -629,14 +632,23 @@ qs_get_child_node(Doc *UNUSED(doc), Node *node) {
 
 
 Node *
-qs_get_next_node(Doc *UNUSED(doc), Node *node) {
+qs_get_next_node(Doc *UNUSED(doc), Node *node) 
+{
   return node->next;
 }
 
 
+Node *
+qs_get_prev_node(Doc *UNUSED(doc), Node *node) 
+{
+  return node->prev;
+}
+
+
 
 Attr *
-qs_get_attr(Doc *UNUSED(doc), Node *node) {
+qs_get_attr(Doc *UNUSED(doc), Node *node) 
+{
   return node->attr;
 }
 
